/// <reference types="node" />
import { AppProps } from 'next/app';
import { GetServerSideProps } from 'next';
import { ApolloClient, NormalizedCacheObject } from '@apollo/client';
import { ApolloClientConfig, GetServerSideApolloProps, GetServerSideApolloPropsOptions, InitializeApolloArgs, QueryHydrationMap } from './types';
export declare let __APOLLO_CLIENT__: ApolloClient<NormalizedCacheObject> | undefined;
export interface NextApolloClientOptions {
    client: ApolloClientConfig;
    hydrationMap?: QueryHydrationMap;
}
export declare class NextApolloClient<THydrationMap extends QueryHydrationMap> {
    private readonly _client;
    private readonly _hydrationMap?;
    constructor({ client, hydrationMap }: NextApolloClientOptions);
    private createApolloClient;
    initializeApollo: ({ headers, initialState }?: InitializeApolloArgs) => ApolloClient<NormalizedCacheObject>;
    private addApolloState;
    useApolloClient: (pageProps: AppProps['pageProps']) => ApolloClient<NormalizedCacheObject>;
    getServerSideApolloProps: <TProps = Record<string, any>>({ hydrateQueries, onClientInitialized, onHydrationComplete, }?: GetServerSideApolloPropsOptions<THydrationMap, (keyof THydrationMap)[], TProps>) => GetServerSideProps<GetServerSideApolloProps & TProps, import("querystring").ParsedUrlQuery, import("next").PreviewData>;
}
